# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/chaincode_shim.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.peer import chaincode_event_pb2 as hfc_dot_protos_dot_peer_dot_chaincode__event__pb2
from hfc.protos.peer import proposal_pb2 as hfc_dot_protos_dot_peer_dot_proposal__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/chaincode_shim.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n$hfc/protos/peer/chaincode_shim.proto\x12\x06protos\x1a%hfc/protos/peer/chaincode_event.proto\x1a\x1ehfc/protos/peer/proposal.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf6\x04\n\x10\x43haincodeMessage\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.protos.ChaincodeMessage.Type\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0c\n\x04txid\x18\x04 \x01(\t\x12(\n\x08proposal\x18\x05 \x01(\x0b\x32\x16.protos.SignedProposal\x12/\n\x0f\x63haincode_event\x18\x06 \x01(\x0b\x32\x16.protos.ChaincodeEvent\x12\x12\n\nchannel_id\x18\x07 \x01(\t\"\xf7\x02\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08REGISTER\x10\x01\x12\x0e\n\nREGISTERED\x10\x02\x12\x08\n\x04INIT\x10\x03\x12\t\n\x05READY\x10\x04\x12\x0f\n\x0bTRANSACTION\x10\x05\x12\r\n\tCOMPLETED\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\r\n\tGET_STATE\x10\x08\x12\r\n\tPUT_STATE\x10\t\x12\r\n\tDEL_STATE\x10\n\x12\x14\n\x10INVOKE_CHAINCODE\x10\x0b\x12\x0c\n\x08RESPONSE\x10\r\x12\x16\n\x12GET_STATE_BY_RANGE\x10\x0e\x12\x14\n\x10GET_QUERY_RESULT\x10\x0f\x12\x14\n\x10QUERY_STATE_NEXT\x10\x10\x12\x15\n\x11QUERY_STATE_CLOSE\x10\x11\x12\r\n\tKEEPALIVE\x10\x12\x12\x17\n\x13GET_HISTORY_FOR_KEY\x10\x13\x12\x16\n\x12GET_STATE_METADATA\x10\x14\x12\x16\n\x12PUT_STATE_METADATA\x10\x15\"+\n\x08GetState\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\"3\n\x10GetStateMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\":\n\x08PutState\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x12\n\ncollection\x18\x03 \x01(\t\"\\\n\x10PutStateMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\'\n\x08metadata\x18\x04 \x01(\x0b\x32\x15.protos.StateMetadata\"+\n\x08\x44\x65lState\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\"Y\n\x0fGetStateByRange\x12\x10\n\x08startKey\x18\x01 \x01(\t\x12\x0e\n\x06\x65ndKey\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\x10\n\x08metadata\x18\x04 \x01(\x0c\"E\n\x0eGetQueryResult\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"3\n\rQueryMetadata\x12\x10\n\x08pageSize\x18\x01 \x01(\x05\x12\x10\n\x08\x62ookmark\x18\x02 \x01(\t\"\x1f\n\x10GetHistoryForKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x1c\n\x0eQueryStateNext\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x0fQueryStateClose\x12\n\n\x02id\x18\x01 \x01(\t\"\'\n\x10QueryResultBytes\x12\x13\n\x0bresultBytes\x18\x01 \x01(\x0c\"j\n\rQueryResponse\x12)\n\x07results\x18\x01 \x03(\x0b\x32\x18.protos.QueryResultBytes\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08metadata\x18\x04 \x01(\x0c\"H\n\x15QueryResponseMetadata\x12\x1d\n\x15\x66\x65tched_records_count\x18\x01 \x01(\x05\x12\x10\n\x08\x62ookmark\x18\x02 \x01(\t\"/\n\rStateMetadata\x12\x0f\n\x07metakey\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"=\n\x13StateMetadataResult\x12&\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x15.protos.StateMetadata2X\n\x10\x43haincodeSupport\x12\x44\n\x08Register\x12\x18.protos.ChaincodeMessage\x1a\x18.protos.ChaincodeMessage\"\x00(\x01\x30\x01\x42O\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_peer_dot_chaincode__event__pb2.DESCRIPTOR,hfc_dot_protos_dot_peer_dot_proposal__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_CHAINCODEMESSAGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='protos.ChaincodeMessage.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REGISTER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REGISTERED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_STATE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUT_STATE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEL_STATE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVOKE_CHAINCODE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_STATE_BY_RANGE', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_QUERY_RESULT', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_STATE_NEXT', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_STATE_CLOSE', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEEPALIVE', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_HISTORY_FOR_KEY', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_STATE_METADATA', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUT_STATE_METADATA', index=20, number=21,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=408,
  serialized_end=783,
)
_sym_db.RegisterEnumDescriptor(_CHAINCODEMESSAGE_TYPE)


_CHAINCODEMESSAGE = _descriptor.Descriptor(
  name='ChaincodeMessage',
  full_name='protos.ChaincodeMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='protos.ChaincodeMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='protos.ChaincodeMessage.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='protos.ChaincodeMessage.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txid', full_name='protos.ChaincodeMessage.txid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposal', full_name='protos.ChaincodeMessage.proposal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chaincode_event', full_name='protos.ChaincodeMessage.chaincode_event', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='protos.ChaincodeMessage.channel_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHAINCODEMESSAGE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=783,
)


_GETSTATE = _descriptor.Descriptor(
  name='GetState',
  full_name='protos.GetState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.GetState.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.GetState.collection', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=828,
)


_GETSTATEMETADATA = _descriptor.Descriptor(
  name='GetStateMetadata',
  full_name='protos.GetStateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.GetStateMetadata.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.GetStateMetadata.collection', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=881,
)


_PUTSTATE = _descriptor.Descriptor(
  name='PutState',
  full_name='protos.PutState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.PutState.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protos.PutState.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.PutState.collection', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=941,
)


_PUTSTATEMETADATA = _descriptor.Descriptor(
  name='PutStateMetadata',
  full_name='protos.PutStateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.PutStateMetadata.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.PutStateMetadata.collection', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='protos.PutStateMetadata.metadata', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1035,
)


_DELSTATE = _descriptor.Descriptor(
  name='DelState',
  full_name='protos.DelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.DelState.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.DelState.collection', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1080,
)


_GETSTATEBYRANGE = _descriptor.Descriptor(
  name='GetStateByRange',
  full_name='protos.GetStateByRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startKey', full_name='protos.GetStateByRange.startKey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endKey', full_name='protos.GetStateByRange.endKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.GetStateByRange.collection', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='protos.GetStateByRange.metadata', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1171,
)


_GETQUERYRESULT = _descriptor.Descriptor(
  name='GetQueryResult',
  full_name='protos.GetQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='protos.GetQueryResult.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='protos.GetQueryResult.collection', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='protos.GetQueryResult.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1242,
)


_QUERYMETADATA = _descriptor.Descriptor(
  name='QueryMetadata',
  full_name='protos.QueryMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pageSize', full_name='protos.QueryMetadata.pageSize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bookmark', full_name='protos.QueryMetadata.bookmark', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1295,
)


_GETHISTORYFORKEY = _descriptor.Descriptor(
  name='GetHistoryForKey',
  full_name='protos.GetHistoryForKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.GetHistoryForKey.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1297,
  serialized_end=1328,
)


_QUERYSTATENEXT = _descriptor.Descriptor(
  name='QueryStateNext',
  full_name='protos.QueryStateNext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.QueryStateNext.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1330,
  serialized_end=1358,
)


_QUERYSTATECLOSE = _descriptor.Descriptor(
  name='QueryStateClose',
  full_name='protos.QueryStateClose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.QueryStateClose.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1360,
  serialized_end=1389,
)


_QUERYRESULTBYTES = _descriptor.Descriptor(
  name='QueryResultBytes',
  full_name='protos.QueryResultBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultBytes', full_name='protos.QueryResultBytes.resultBytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1391,
  serialized_end=1430,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='protos.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='protos.QueryResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_more', full_name='protos.QueryResponse.has_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.QueryResponse.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='protos.QueryResponse.metadata', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1432,
  serialized_end=1538,
)


_QUERYRESPONSEMETADATA = _descriptor.Descriptor(
  name='QueryResponseMetadata',
  full_name='protos.QueryResponseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fetched_records_count', full_name='protos.QueryResponseMetadata.fetched_records_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bookmark', full_name='protos.QueryResponseMetadata.bookmark', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1540,
  serialized_end=1612,
)


_STATEMETADATA = _descriptor.Descriptor(
  name='StateMetadata',
  full_name='protos.StateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metakey', full_name='protos.StateMetadata.metakey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protos.StateMetadata.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1661,
)


_STATEMETADATARESULT = _descriptor.Descriptor(
  name='StateMetadataResult',
  full_name='protos.StateMetadataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='protos.StateMetadataResult.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1663,
  serialized_end=1724,
)

_CHAINCODEMESSAGE.fields_by_name['type'].enum_type = _CHAINCODEMESSAGE_TYPE
_CHAINCODEMESSAGE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHAINCODEMESSAGE.fields_by_name['proposal'].message_type = hfc_dot_protos_dot_peer_dot_proposal__pb2._SIGNEDPROPOSAL
_CHAINCODEMESSAGE.fields_by_name['chaincode_event'].message_type = hfc_dot_protos_dot_peer_dot_chaincode__event__pb2._CHAINCODEEVENT
_CHAINCODEMESSAGE_TYPE.containing_type = _CHAINCODEMESSAGE
_PUTSTATEMETADATA.fields_by_name['metadata'].message_type = _STATEMETADATA
_QUERYRESPONSE.fields_by_name['results'].message_type = _QUERYRESULTBYTES
_STATEMETADATARESULT.fields_by_name['entries'].message_type = _STATEMETADATA
DESCRIPTOR.message_types_by_name['ChaincodeMessage'] = _CHAINCODEMESSAGE
DESCRIPTOR.message_types_by_name['GetState'] = _GETSTATE
DESCRIPTOR.message_types_by_name['GetStateMetadata'] = _GETSTATEMETADATA
DESCRIPTOR.message_types_by_name['PutState'] = _PUTSTATE
DESCRIPTOR.message_types_by_name['PutStateMetadata'] = _PUTSTATEMETADATA
DESCRIPTOR.message_types_by_name['DelState'] = _DELSTATE
DESCRIPTOR.message_types_by_name['GetStateByRange'] = _GETSTATEBYRANGE
DESCRIPTOR.message_types_by_name['GetQueryResult'] = _GETQUERYRESULT
DESCRIPTOR.message_types_by_name['QueryMetadata'] = _QUERYMETADATA
DESCRIPTOR.message_types_by_name['GetHistoryForKey'] = _GETHISTORYFORKEY
DESCRIPTOR.message_types_by_name['QueryStateNext'] = _QUERYSTATENEXT
DESCRIPTOR.message_types_by_name['QueryStateClose'] = _QUERYSTATECLOSE
DESCRIPTOR.message_types_by_name['QueryResultBytes'] = _QUERYRESULTBYTES
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
DESCRIPTOR.message_types_by_name['QueryResponseMetadata'] = _QUERYRESPONSEMETADATA
DESCRIPTOR.message_types_by_name['StateMetadata'] = _STATEMETADATA
DESCRIPTOR.message_types_by_name['StateMetadataResult'] = _STATEMETADATARESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChaincodeMessage = _reflection.GeneratedProtocolMessageType('ChaincodeMessage', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEMESSAGE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeMessage)
  ))
_sym_db.RegisterMessage(ChaincodeMessage)

GetState = _reflection.GeneratedProtocolMessageType('GetState', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.GetState)
  ))
_sym_db.RegisterMessage(GetState)

GetStateMetadata = _reflection.GeneratedProtocolMessageType('GetStateMetadata', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATEMETADATA,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.GetStateMetadata)
  ))
_sym_db.RegisterMessage(GetStateMetadata)

PutState = _reflection.GeneratedProtocolMessageType('PutState', (_message.Message,), dict(
  DESCRIPTOR = _PUTSTATE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.PutState)
  ))
_sym_db.RegisterMessage(PutState)

PutStateMetadata = _reflection.GeneratedProtocolMessageType('PutStateMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PUTSTATEMETADATA,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.PutStateMetadata)
  ))
_sym_db.RegisterMessage(PutStateMetadata)

DelState = _reflection.GeneratedProtocolMessageType('DelState', (_message.Message,), dict(
  DESCRIPTOR = _DELSTATE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.DelState)
  ))
_sym_db.RegisterMessage(DelState)

GetStateByRange = _reflection.GeneratedProtocolMessageType('GetStateByRange', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATEBYRANGE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.GetStateByRange)
  ))
_sym_db.RegisterMessage(GetStateByRange)

GetQueryResult = _reflection.GeneratedProtocolMessageType('GetQueryResult', (_message.Message,), dict(
  DESCRIPTOR = _GETQUERYRESULT,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.GetQueryResult)
  ))
_sym_db.RegisterMessage(GetQueryResult)

QueryMetadata = _reflection.GeneratedProtocolMessageType('QueryMetadata', (_message.Message,), dict(
  DESCRIPTOR = _QUERYMETADATA,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.QueryMetadata)
  ))
_sym_db.RegisterMessage(QueryMetadata)

GetHistoryForKey = _reflection.GeneratedProtocolMessageType('GetHistoryForKey', (_message.Message,), dict(
  DESCRIPTOR = _GETHISTORYFORKEY,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.GetHistoryForKey)
  ))
_sym_db.RegisterMessage(GetHistoryForKey)

QueryStateNext = _reflection.GeneratedProtocolMessageType('QueryStateNext', (_message.Message,), dict(
  DESCRIPTOR = _QUERYSTATENEXT,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.QueryStateNext)
  ))
_sym_db.RegisterMessage(QueryStateNext)

QueryStateClose = _reflection.GeneratedProtocolMessageType('QueryStateClose', (_message.Message,), dict(
  DESCRIPTOR = _QUERYSTATECLOSE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.QueryStateClose)
  ))
_sym_db.RegisterMessage(QueryStateClose)

QueryResultBytes = _reflection.GeneratedProtocolMessageType('QueryResultBytes', (_message.Message,), dict(
  DESCRIPTOR = _QUERYRESULTBYTES,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.QueryResultBytes)
  ))
_sym_db.RegisterMessage(QueryResultBytes)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUERYRESPONSE,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.QueryResponse)
  ))
_sym_db.RegisterMessage(QueryResponse)

QueryResponseMetadata = _reflection.GeneratedProtocolMessageType('QueryResponseMetadata', (_message.Message,), dict(
  DESCRIPTOR = _QUERYRESPONSEMETADATA,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.QueryResponseMetadata)
  ))
_sym_db.RegisterMessage(QueryResponseMetadata)

StateMetadata = _reflection.GeneratedProtocolMessageType('StateMetadata', (_message.Message,), dict(
  DESCRIPTOR = _STATEMETADATA,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.StateMetadata)
  ))
_sym_db.RegisterMessage(StateMetadata)

StateMetadataResult = _reflection.GeneratedProtocolMessageType('StateMetadataResult', (_message.Message,), dict(
  DESCRIPTOR = _STATEMETADATARESULT,
  __module__ = 'hfc.protos.peer.chaincode_shim_pb2'
  # @@protoc_insertion_point(class_scope:protos.StateMetadataResult)
  ))
_sym_db.RegisterMessage(StateMetadataResult)


DESCRIPTOR._options = None

_CHAINCODESUPPORT = _descriptor.ServiceDescriptor(
  name='ChaincodeSupport',
  full_name='protos.ChaincodeSupport',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1726,
  serialized_end=1814,
  methods=[
  _descriptor.MethodDescriptor(
    name='Register',
    full_name='protos.ChaincodeSupport.Register',
    index=0,
    containing_service=None,
    input_type=_CHAINCODEMESSAGE,
    output_type=_CHAINCODEMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHAINCODESUPPORT)

DESCRIPTOR.services_by_name['ChaincodeSupport'] = _CHAINCODESUPPORT

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/token/expectations.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from hfc.protos.token import transaction_pb2 as hfc_dot_protos_dot_token_dot_transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/token/expectations.proto',
  package='token',
  syntax='proto3',
  serialized_options=_b('\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/token'),
  serialized_pb=_b('\n#hfc/protos/token/expectations.proto\x12\x05token\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"hfc/protos/token/transaction.proto\"W\n\x10TokenExpectation\x12\x34\n\x11plain_expectation\x18\x01 \x01(\x0b\x32\x17.token.PlainExpectationH\x00\x42\r\n\x0b\x45xpectation\"\x97\x01\n\x10PlainExpectation\x12:\n\x12import_expectation\x18\x01 \x01(\x0b\x32\x1c.token.PlainTokenExpectationH\x00\x12<\n\x14transfer_expectation\x18\x02 \x01(\x0b\x32\x1c.token.PlainTokenExpectationH\x00\x42\t\n\x07payload\"<\n\x15PlainTokenExpectation\x12#\n\x07outputs\x18\x01 \x03(\x0b\x32\x12.token.PlainOutputBQ\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/tokenb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,hfc_dot_protos_dot_token_dot_transaction__pb2.DESCRIPTOR,])




_TOKENEXPECTATION = _descriptor.Descriptor(
  name='TokenExpectation',
  full_name='token.TokenExpectation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plain_expectation', full_name='token.TokenExpectation.plain_expectation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Expectation', full_name='token.TokenExpectation.Expectation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=115,
  serialized_end=202,
)


_PLAINEXPECTATION = _descriptor.Descriptor(
  name='PlainExpectation',
  full_name='token.PlainExpectation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='import_expectation', full_name='token.PlainExpectation.import_expectation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_expectation', full_name='token.PlainExpectation.transfer_expectation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='token.PlainExpectation.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=205,
  serialized_end=356,
)


_PLAINTOKENEXPECTATION = _descriptor.Descriptor(
  name='PlainTokenExpectation',
  full_name='token.PlainTokenExpectation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='token.PlainTokenExpectation.outputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=418,
)

_TOKENEXPECTATION.fields_by_name['plain_expectation'].message_type = _PLAINEXPECTATION
_TOKENEXPECTATION.oneofs_by_name['Expectation'].fields.append(
  _TOKENEXPECTATION.fields_by_name['plain_expectation'])
_TOKENEXPECTATION.fields_by_name['plain_expectation'].containing_oneof = _TOKENEXPECTATION.oneofs_by_name['Expectation']
_PLAINEXPECTATION.fields_by_name['import_expectation'].message_type = _PLAINTOKENEXPECTATION
_PLAINEXPECTATION.fields_by_name['transfer_expectation'].message_type = _PLAINTOKENEXPECTATION
_PLAINEXPECTATION.oneofs_by_name['payload'].fields.append(
  _PLAINEXPECTATION.fields_by_name['import_expectation'])
_PLAINEXPECTATION.fields_by_name['import_expectation'].containing_oneof = _PLAINEXPECTATION.oneofs_by_name['payload']
_PLAINEXPECTATION.oneofs_by_name['payload'].fields.append(
  _PLAINEXPECTATION.fields_by_name['transfer_expectation'])
_PLAINEXPECTATION.fields_by_name['transfer_expectation'].containing_oneof = _PLAINEXPECTATION.oneofs_by_name['payload']
_PLAINTOKENEXPECTATION.fields_by_name['outputs'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._PLAINOUTPUT
DESCRIPTOR.message_types_by_name['TokenExpectation'] = _TOKENEXPECTATION
DESCRIPTOR.message_types_by_name['PlainExpectation'] = _PLAINEXPECTATION
DESCRIPTOR.message_types_by_name['PlainTokenExpectation'] = _PLAINTOKENEXPECTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenExpectation = _reflection.GeneratedProtocolMessageType('TokenExpectation', (_message.Message,), dict(
  DESCRIPTOR = _TOKENEXPECTATION,
  __module__ = 'hfc.protos.token.expectations_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenExpectation)
  ))
_sym_db.RegisterMessage(TokenExpectation)

PlainExpectation = _reflection.GeneratedProtocolMessageType('PlainExpectation', (_message.Message,), dict(
  DESCRIPTOR = _PLAINEXPECTATION,
  __module__ = 'hfc.protos.token.expectations_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainExpectation)
  ))
_sym_db.RegisterMessage(PlainExpectation)

PlainTokenExpectation = _reflection.GeneratedProtocolMessageType('PlainTokenExpectation', (_message.Message,), dict(
  DESCRIPTOR = _PLAINTOKENEXPECTATION,
  __module__ = 'hfc.protos.token.expectations_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainTokenExpectation)
  ))
_sym_db.RegisterMessage(PlainTokenExpectation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 281165273@qq.com. All Rights Reserved.
#
# SPDX-License-Identifier: Apache-2.0

import logging
import threading

from hfc.protos.discovery import protocol_pb2_grpc
from hfc.protos.peer import peer_pb2_grpc, events_pb2_grpc
from hfc.util.channel import create_grpc_channel
from hfc.util.utils import stream_envelope

DEFAULT_PEER_ENDPOINT = 'localhost:7051'

_logger = logging.getLogger(__name__ + ".peer")


# TODO should extend Remote base class as in fabric-node-sdk


class Peer(object):
    """ A peer node in the network.

    It has a specific gRPC channel address.
    """

    def __init__(self, name='peer', endpoint=DEFAULT_PEER_ENDPOINT,
                 tls_ca_cert_file=None, client_key_file=None,
                 client_cert_file=None, opts=None):
        """

        :param endpoint: Endpoint of the peer's gRPC service
        :param tls_ca_cert_file: file path of tls root ca's certificate
        :param client_key: file path for Private key used for TLS when making
         client connections
        :param client_cert: file path for X.509 certificate used for TLS when
         making client connections
        :param opts: optional params
        """
        self._name = name
        self._lock = threading.RLock()
        self._channels = []
        self._endpoint = endpoint
        if opts:
            self._grpc_options = {key: value for (key, value) in opts}
        else:
            self._grpc_options = dict()
        self._ssl_target_name = None
        self._tls_ca_certs_path = tls_ca_cert_file
        self._client_key_path = client_key_file
        self._client_cert_path = client_cert_file
        self._channel = create_grpc_channel(self._endpoint, tls_ca_cert_file,
                                            client_key_file, client_cert_file,
                                            opts)
        self._endorser_client = peer_pb2_grpc.EndorserStub(self._channel)
        self._discovery_client = protocol_pb2_grpc.DiscoveryStub(self._channel)
        self._event_client = events_pb2_grpc.DeliverStub(self._channel)

    def send_proposal(self, proposal):
        """Send an endorsement proposal to endorser

        :param proposal: The endorsement proposal
        :return: ProposalResponse or exception
        :rtype: Response/Exception
        """

        _logger.debug("Send proposal={}".format(proposal))
        return self._endorser_client.ProcessProposal(proposal)

    def send_discovery(self, request):
        """Send an request to discovery server

        :param request: a signed request
        :return: QueryResult or exception
        :rtype: Result/Exception
        """
        _logger.debug("Send discovery={}".format(request))
        return self._discovery_client.Discover(request)

    def init_with_bundle(self, info):
        """
        Init the peer with given info dict
        :param info: Dict including all info, e.g., endpoint, grpc option
        :return: True or False
        """
        try:
            self._endpoint = info['url']
            self._grpc_options = info['grpcOptions']
            self._tls_ca_certs_path = info['tlsCACerts']['path']
            if 'clientKey' in info:
                self._client_key_path = info['clientKey']['path']
            if 'clientCert' in info:
                self._client_cert_path = info['clientCert']['path']
            self._ssl_target_name = self._grpc_options[
                'grpc.ssl_target_name_override']
            self._channel = create_grpc_channel(
                self._endpoint,
                self._tls_ca_certs_path,
                self._client_key_path,
                self._client_cert_path,
                opts=[(opt, value) for opt, value in
                      self._grpc_options.items()])
            self._endorser_client = peer_pb2_grpc.EndorserStub(self._channel)
            self._discovery_client = protocol_pb2_grpc.DiscoveryStub(
                self._channel)
            self._event_client = events_pb2_grpc.DeliverStub(self._channel)

        except KeyError as e:
            _logger.error(e)
            return False
        return True

    def get_attrs(self):
        return ",".join("{}={}"
                        .format(k, getattr(self, k))
                        for k in self.__dict__.keys())

    def __str__(self):
        return "[{}:{}]".format(self.__class__.__name__, self.get_attrs())

    @property
    def endpoint(self):
        """Return the endpoint of the peer.

        :return: endpoint
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        self._endpoint = endpoint

    @property
    def name(self):
        """Get the peer name

        :return: The peer name
        :rtype: str
        """
        return self._name

    def join(self, chan):
        """Join a channel

        :param chan: a channel instance
        """
        with self._lock:
            self._channels.append(chan)

    @property
    def channels(self):
        with self._lock:
            return self._channels

    def delivery(self, envelope, scheduler=None, filtered=True):
        """Send an delivery envelop to event service.

        :param envelope: The message envelope
        :param scheduler: defaults to None
        :param filtered: defaults to True
        :type filtered: bool
        :return: orderer_response or exception
        """
        _logger.debug("Send envelope={}".format(envelope))

        if filtered:
            delivery_result = self._event_client.DeliverFiltered(
                stream_envelope(envelope))
        else:
            delivery_result = self._event_client.Deliver(
                stream_envelope(envelope))
        return delivery_result

    def set_tls_client_cert_and_key(self, client_key_file=None,
                                    client_cert_file=None):
        """Set tls client's cert and key for mutual tls

        :param client_key_file: file path for Private key used for TLS when
                making client connections, defaults to None
        :type client_key_file: str
        :param client_cert_file: file path for X.509 certificate used for TLS
                when making client connections, defaults to None
        :type client_cert_file: str
        :return: set success value
        :rtype: bool
        """

        try:
            self._client_key_path = client_key_file
            self._client_cert_path = client_cert_file
            self._channel = create_grpc_channel(
                self._endpoint,
                self._tls_ca_certs_path,
                self._client_key_path,
                self._client_cert_path,
                opts=[(opt, value) for opt, value in
                      self._grpc_options.items()])
            self._endorser_client = peer_pb2_grpc.EndorserStub(self._channel)
            self._discovery_client = protocol_pb2_grpc.DiscoveryStub(
                self._channel)
            self._event_client = events_pb2_grpc.DeliverStub(self._channel)
        except Exception:
            return False
        return True


def create_peer(endpoint=DEFAULT_PEER_ENDPOINT, tls_cacerts=None,
                client_key=None, client_cert=None, opts=None):
    """Factory method to construct a peer instance

    :param endpoint: endpoint, defaults to DEFAULT_PEER_ENDPOINT
    :param tls_cacerts: pem, defaults to None
    :param client_key: pem, defaults to None
    :param client_cert: pem, defaults to None
    :param opts: opts, defaults to None
    :type opts: opts
    :return: a peer instance
    """
    return Peer(endpoint=endpoint, tls_ca_cert_file=tls_cacerts,
                client_key_file=client_key, client_cert_file=client_cert,
                opts=opts)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from hfc.protos.peer import chaincode_shim_pb2 as hfc_dot_protos_dot_peer_dot_chaincode__shim__pb2


class ChaincodeSupportStub(object):
  """Interface that provides support to chaincode execution. ChaincodeContext
  provides the context necessary for the server to respond appropriately.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Register = channel.stream_stream(
        '/protos.ChaincodeSupport/Register',
        request_serializer=hfc_dot_protos_dot_peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
        )


class ChaincodeSupportServicer(object):
  """Interface that provides support to chaincode execution. ChaincodeContext
  provides the context necessary for the server to respond appropriately.
  """

  def Register(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ChaincodeSupportServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Register': grpc.stream_stream_rpc_method_handler(
          servicer.Register,
          request_deserializer=hfc_dot_protos_dot_peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'protos.ChaincodeSupport', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/resources.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.common import configtx_pb2 as hfc_dot_protos_dot_common_dot_configtx__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/resources.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n\x1fhfc/protos/peer/resources.proto\x12\x06protos\x1a hfc/protos/common/configtx.proto\"4\n\x13\x43haincodeIdentifier\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\t\"5\n\x13\x43haincodeValidation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x61rgument\x18\x02 \x01(\x0c\"*\n\x08VSCCArgs\x12\x1e\n\x16\x65ndorsement_policy_ref\x18\x01 \x01(\t\"$\n\x14\x43haincodeEndorsement\x12\x0c\n\x04name\x18\x01 \x01(\t\"^\n\nConfigTree\x12&\n\x0e\x63hannel_config\x18\x01 \x01(\x0b\x32\x0e.common.Config\x12(\n\x10resources_config\x18\x02 \x01(\x0b\x32\x0e.common.ConfigBO\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_common_dot_configtx__pb2.DESCRIPTOR,])




_CHAINCODEIDENTIFIER = _descriptor.Descriptor(
  name='ChaincodeIdentifier',
  full_name='protos.ChaincodeIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='protos.ChaincodeIdentifier.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='protos.ChaincodeIdentifier.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=129,
)


_CHAINCODEVALIDATION = _descriptor.Descriptor(
  name='ChaincodeValidation',
  full_name='protos.ChaincodeValidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ChaincodeValidation.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='protos.ChaincodeValidation.argument', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=184,
)


_VSCCARGS = _descriptor.Descriptor(
  name='VSCCArgs',
  full_name='protos.VSCCArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endorsement_policy_ref', full_name='protos.VSCCArgs.endorsement_policy_ref', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=228,
)


_CHAINCODEENDORSEMENT = _descriptor.Descriptor(
  name='ChaincodeEndorsement',
  full_name='protos.ChaincodeEndorsement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ChaincodeEndorsement.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=266,
)


_CONFIGTREE = _descriptor.Descriptor(
  name='ConfigTree',
  full_name='protos.ConfigTree',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_config', full_name='protos.ConfigTree.channel_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_config', full_name='protos.ConfigTree.resources_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=362,
)

_CONFIGTREE.fields_by_name['channel_config'].message_type = hfc_dot_protos_dot_common_dot_configtx__pb2._CONFIG
_CONFIGTREE.fields_by_name['resources_config'].message_type = hfc_dot_protos_dot_common_dot_configtx__pb2._CONFIG
DESCRIPTOR.message_types_by_name['ChaincodeIdentifier'] = _CHAINCODEIDENTIFIER
DESCRIPTOR.message_types_by_name['ChaincodeValidation'] = _CHAINCODEVALIDATION
DESCRIPTOR.message_types_by_name['VSCCArgs'] = _VSCCARGS
DESCRIPTOR.message_types_by_name['ChaincodeEndorsement'] = _CHAINCODEENDORSEMENT
DESCRIPTOR.message_types_by_name['ConfigTree'] = _CONFIGTREE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChaincodeIdentifier = _reflection.GeneratedProtocolMessageType('ChaincodeIdentifier', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEIDENTIFIER,
  __module__ = 'hfc.protos.peer.resources_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeIdentifier)
  ))
_sym_db.RegisterMessage(ChaincodeIdentifier)

ChaincodeValidation = _reflection.GeneratedProtocolMessageType('ChaincodeValidation', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEVALIDATION,
  __module__ = 'hfc.protos.peer.resources_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeValidation)
  ))
_sym_db.RegisterMessage(ChaincodeValidation)

VSCCArgs = _reflection.GeneratedProtocolMessageType('VSCCArgs', (_message.Message,), dict(
  DESCRIPTOR = _VSCCARGS,
  __module__ = 'hfc.protos.peer.resources_pb2'
  # @@protoc_insertion_point(class_scope:protos.VSCCArgs)
  ))
_sym_db.RegisterMessage(VSCCArgs)

ChaincodeEndorsement = _reflection.GeneratedProtocolMessageType('ChaincodeEndorsement', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEENDORSEMENT,
  __module__ = 'hfc.protos.peer.resources_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeEndorsement)
  ))
_sym_db.RegisterMessage(ChaincodeEndorsement)

ConfigTree = _reflection.GeneratedProtocolMessageType('ConfigTree', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGTREE,
  __module__ = 'hfc.protos.peer.resources_pb2'
  # @@protoc_insertion_point(class_scope:protos.ConfigTree)
  ))
_sym_db.RegisterMessage(ConfigTree)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/msp/msp_principal.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/msp/msp_principal.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('\n$org.hyperledger.fabric.protos.commonZ(github.com/hyperledger/fabric/protos/msp'),
  serialized_pb=_b('\n\"hfc/protos/msp/msp_principal.proto\x12\x06\x63ommon\"\xc6\x01\n\x0cMSPPrincipal\x12\x45\n\x18principal_classification\x18\x01 \x01(\x0e\x32#.common.MSPPrincipal.Classification\x12\x11\n\tprincipal\x18\x02 \x01(\x0c\"\\\n\x0e\x43lassification\x12\x08\n\x04ROLE\x10\x00\x12\x15\n\x11ORGANIZATION_UNIT\x10\x01\x12\x0c\n\x08IDENTITY\x10\x02\x12\r\n\tANONYMITY\x10\x03\x12\x0c\n\x08\x43OMBINED\x10\x04\"q\n\x10OrganizationUnit\x12\x16\n\x0emsp_identifier\x18\x01 \x01(\t\x12&\n\x1eorganizational_unit_identifier\x18\x02 \x01(\t\x12\x1d\n\x15\x63\x65rtifiers_identifier\x18\x03 \x01(\x0c\"\x88\x01\n\x07MSPRole\x12\x16\n\x0emsp_identifier\x18\x01 \x01(\t\x12)\n\x04role\x18\x02 \x01(\x0e\x32\x1b.common.MSPRole.MSPRoleType\":\n\x0bMSPRoleType\x12\n\n\x06MEMBER\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\n\n\x06\x43LIENT\x10\x02\x12\x08\n\x04PEER\x10\x03\"\x9d\x01\n\x14MSPIdentityAnonymity\x12M\n\x0e\x61nonymity_type\x18\x01 \x01(\x0e\x32\x35.common.MSPIdentityAnonymity.MSPIdentityAnonymityType\"6\n\x18MSPIdentityAnonymityType\x12\x0b\n\x07NOMINAL\x10\x00\x12\r\n\tANONYMOUS\x10\x01\"=\n\x11\x43ombinedPrincipal\x12(\n\nprincipals\x18\x01 \x03(\x0b\x32\x14.common.MSPPrincipalBP\n$org.hyperledger.fabric.protos.commonZ(github.com/hyperledger/fabric/protos/mspb\x06proto3')
)



_MSPPRINCIPAL_CLASSIFICATION = _descriptor.EnumDescriptor(
  name='Classification',
  full_name='common.MSPPrincipal.Classification',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORGANIZATION_UNIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDENTITY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANONYMITY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMBINED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=245,
)
_sym_db.RegisterEnumDescriptor(_MSPPRINCIPAL_CLASSIFICATION)

_MSPROLE_MSPROLETYPE = _descriptor.EnumDescriptor(
  name='MSPRoleType',
  full_name='common.MSPRole.MSPRoleType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PEER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=441,
  serialized_end=499,
)
_sym_db.RegisterEnumDescriptor(_MSPROLE_MSPROLETYPE)

_MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE = _descriptor.EnumDescriptor(
  name='MSPIdentityAnonymityType',
  full_name='common.MSPIdentityAnonymity.MSPIdentityAnonymityType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOMINAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANONYMOUS', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=605,
  serialized_end=659,
)
_sym_db.RegisterEnumDescriptor(_MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE)


_MSPPRINCIPAL = _descriptor.Descriptor(
  name='MSPPrincipal',
  full_name='common.MSPPrincipal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='principal_classification', full_name='common.MSPPrincipal.principal_classification', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal', full_name='common.MSPPrincipal.principal', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MSPPRINCIPAL_CLASSIFICATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=245,
)


_ORGANIZATIONUNIT = _descriptor.Descriptor(
  name='OrganizationUnit',
  full_name='common.OrganizationUnit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msp_identifier', full_name='common.OrganizationUnit.msp_identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organizational_unit_identifier', full_name='common.OrganizationUnit.organizational_unit_identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certifiers_identifier', full_name='common.OrganizationUnit.certifiers_identifier', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=360,
)


_MSPROLE = _descriptor.Descriptor(
  name='MSPRole',
  full_name='common.MSPRole',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msp_identifier', full_name='common.MSPRole.msp_identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='common.MSPRole.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MSPROLE_MSPROLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=499,
)


_MSPIDENTITYANONYMITY = _descriptor.Descriptor(
  name='MSPIdentityAnonymity',
  full_name='common.MSPIdentityAnonymity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='anonymity_type', full_name='common.MSPIdentityAnonymity.anonymity_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=659,
)


_COMBINEDPRINCIPAL = _descriptor.Descriptor(
  name='CombinedPrincipal',
  full_name='common.CombinedPrincipal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='principals', full_name='common.CombinedPrincipal.principals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=722,
)

_MSPPRINCIPAL.fields_by_name['principal_classification'].enum_type = _MSPPRINCIPAL_CLASSIFICATION
_MSPPRINCIPAL_CLASSIFICATION.containing_type = _MSPPRINCIPAL
_MSPROLE.fields_by_name['role'].enum_type = _MSPROLE_MSPROLETYPE
_MSPROLE_MSPROLETYPE.containing_type = _MSPROLE
_MSPIDENTITYANONYMITY.fields_by_name['anonymity_type'].enum_type = _MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE
_MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE.containing_type = _MSPIDENTITYANONYMITY
_COMBINEDPRINCIPAL.fields_by_name['principals'].message_type = _MSPPRINCIPAL
DESCRIPTOR.message_types_by_name['MSPPrincipal'] = _MSPPRINCIPAL
DESCRIPTOR.message_types_by_name['OrganizationUnit'] = _ORGANIZATIONUNIT
DESCRIPTOR.message_types_by_name['MSPRole'] = _MSPROLE
DESCRIPTOR.message_types_by_name['MSPIdentityAnonymity'] = _MSPIDENTITYANONYMITY
DESCRIPTOR.message_types_by_name['CombinedPrincipal'] = _COMBINEDPRINCIPAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MSPPrincipal = _reflection.GeneratedProtocolMessageType('MSPPrincipal', (_message.Message,), dict(
  DESCRIPTOR = _MSPPRINCIPAL,
  __module__ = 'hfc.protos.msp.msp_principal_pb2'
  # @@protoc_insertion_point(class_scope:common.MSPPrincipal)
  ))
_sym_db.RegisterMessage(MSPPrincipal)

OrganizationUnit = _reflection.GeneratedProtocolMessageType('OrganizationUnit', (_message.Message,), dict(
  DESCRIPTOR = _ORGANIZATIONUNIT,
  __module__ = 'hfc.protos.msp.msp_principal_pb2'
  # @@protoc_insertion_point(class_scope:common.OrganizationUnit)
  ))
_sym_db.RegisterMessage(OrganizationUnit)

MSPRole = _reflection.GeneratedProtocolMessageType('MSPRole', (_message.Message,), dict(
  DESCRIPTOR = _MSPROLE,
  __module__ = 'hfc.protos.msp.msp_principal_pb2'
  # @@protoc_insertion_point(class_scope:common.MSPRole)
  ))
_sym_db.RegisterMessage(MSPRole)

MSPIdentityAnonymity = _reflection.GeneratedProtocolMessageType('MSPIdentityAnonymity', (_message.Message,), dict(
  DESCRIPTOR = _MSPIDENTITYANONYMITY,
  __module__ = 'hfc.protos.msp.msp_principal_pb2'
  # @@protoc_insertion_point(class_scope:common.MSPIdentityAnonymity)
  ))
_sym_db.RegisterMessage(MSPIdentityAnonymity)

CombinedPrincipal = _reflection.GeneratedProtocolMessageType('CombinedPrincipal', (_message.Message,), dict(
  DESCRIPTOR = _COMBINEDPRINCIPAL,
  __module__ = 'hfc.protos.msp.msp_principal_pb2'
  # @@protoc_insertion_point(class_scope:common.CombinedPrincipal)
  ))
_sym_db.RegisterMessage(CombinedPrincipal)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# SPDX-License-Identifier: Apache-2.0

import logging
from hfc.fabric.orderer import Orderer
from hfc.fabric.transaction.tx_context import TXContext
from hfc.fabric.transaction.tx_proposal_request import TXProposalRequest
from hfc.util.crypto.crypto import ecies
from hfc.util import utils
from test.integration.utils import get_orderer_org_user, get_peer_org_user
from test.integration.config import E2E_CONFIG
test_network = E2E_CONFIG['test-network']

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)


def build_channel_request(client, channel_tx, channel_name):
    """
    Args:
        client: the client instance
        channel_tx: channel config file
        channel_name: channel name
    return channel request to create a channel
    """

    signatures = []
    prop_req = TXProposalRequest()
    with open(channel_tx, 'rb') as f:
        envelope = f.read()
        config = utils.extract_channel_config(envelope)

    orderer_config = E2E_CONFIG['test-network']['orderer']

    orderer = Orderer(
        endpoint=orderer_config['grpc_endpoint'],
        tls_ca_cert_file=orderer_config['tls_cacerts'],
        opts=(('grpc.ssl_target_name_override',
               'orderer.example.com'),),
    )
    orderer_admin = get_orderer_org_user(state_store=client.state_store)
    orderer_tx_context = TXContext(orderer_admin, ecies(), prop_req, {})
    client.tx_context = orderer_tx_context
    orderer_admin_signature = client.sign_channel_config(config)
    signatures.append(orderer_admin_signature)
    tx_id = orderer_tx_context.tx_id
    nonce = orderer_tx_context.nonce

    org1_admin = get_peer_org_user('org1.example.com', "Admin",
                                   client.state_store)
    org1_tx_context = TXContext(org1_admin, ecies(), prop_req, {})
    client.tx_context = org1_tx_context
    org1_admin_signature = client.sign_channel_config(config)
    signatures.append(org1_admin_signature)

    org2_admin = get_peer_org_user('org2.example.com', "Admin",
                                   client.state_store)
    org2_tx_context = TXContext(org2_admin, ecies(), prop_req, {})
    client.tx_context = org2_tx_context
    org2_admin_signature = client.sign_channel_config(config)
    signatures.append(org2_admin_signature)

    request = {'config': config,
               'signatures': signatures,
               'channel_name': channel_name,
               'orderer': orderer,
               'tx_id': tx_id,
               'nonce': nonce}

    return request


def disconnect(all_ehs):
    """
    disconnect the eventhubs if connected
    Args:
        all_ehs: all the event hubs
    Return: no return value
    """
    for eh in all_ehs:
        if eh.is_connected:
            eh.disconnect()


# This should be deprecated, the code should be included into the client's
# channel_join method
async def build_join_channel_req(org, channel, client):
    """
    For test, there is only one peer.

    Args:
        org: org
        channel: the channel to join
        client: client instance
    Return:
        return request for joining channel
        """

    tx_prop_req = TXProposalRequest()

    # add the orderer
    orderer = client.get_orderer('orderer.example.com')
    channel.add_orderer(orderer)

    # get the genesis block
    orderer_admin = client.get_user('orderer.example.com', 'Admin')
    tx_context = TXContext(orderer_admin, orderer_admin.cryptoSuite,
                           tx_prop_req)

    genesis_block = None
    stream = orderer.get_genesis_block(tx_context, channel.name)
    async for v in stream:
        if v.block is None or v.block == '':
            msg = "fail to get genesis block"
            raise Exception(msg)
        genesis_block = v.block
        break

    genesis_block = genesis_block.SerializeToString()

    org_admin = client.get_user(org, 'Admin')
    tx_context = TXContext(org_admin, org_admin.cryptoSuite, tx_prop_req)

    peer = client.get_peer('peer0.' + org)

    request = {
        "targets": [peer],
        "block": genesis_block,
        "tx_context": tx_context,
        "transient_map": {},
    }

    return request


async def get_stream_result(stream):
    res = []
    async for v in stream:
        logger.debug('Responses of send_transaction:\n {}'.format(v))
        res.append(v)
    return res



# Copyright IBM Corp. 2016 All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import print_function

import os
import unittest
from shutil import rmtree
from hfc.util.keyvaluestore import file_key_value_store

from queue import Queue


class KeyValueStoreTest(unittest.TestCase):
    """Test for key value store. """

    def setUp(self):
        self.base_path = '/tmp/fabric-sdk-py'
        self.path = os.path.join(self.base_path, 'key-value-store')
        self.key = 'test'
        self.value = 'Hello world!'

    def tearDown(self):
        rmtree(self.base_path)

    def test_wrong_path(self):
        """Test illegal path. """
        path = os.path.join(self.base_path, 'wrong-path\0')
        with self.assertRaises(Exception):
            file_key_value_store(path)

    def test_write_and_read(self):
        """Test for setting and getting."""
        key_value_store = file_key_value_store(self.path)
        key_value_store.set_value(self.key, self.value)
        self.assertEqual(key_value_store.get_value(self.key), self.value)

    def test_async_read(self):
        """Test for async getting."""
        key_value_store = file_key_value_store(self.path)
        key_value_store.set_value(self.key, self.value)
        queue = Queue(1)
        key_value_store.async_get_value(self.key) \
            .subscribe(lambda x: queue.put(x))

        self.assertEqual(queue.get(5), self.value)

    def test_async_write(self):
        """Test for async setting."""
        key_value_store = file_key_value_store(self.path)
        queue = Queue(1)
        key_value_store.async_set_value(self.key, self.value) \
            .subscribe(lambda x: queue.put(x))
        self.assertTrue(queue.get(5))


if __name__ == '__main__':
    unittest.main()



# Copyright. All Rights Reserved.
#
# SPDX-License-Identifier: Apache-2.0

import logging


_logger = logging.getLogger(__name__ + ".certificateAuthority")


class certificateAuthority(object):
    """ An organization in the network.

    It contains several members.
    """

    def __init__(self, name='ca'):
        """
        :param name: Name of the organization
        """
        self._name = name
        self._url = None
        self._grpc_options = dict()
        self._tlsCACerts = dict()
        self._registrar = []

    def init_with_bundle(self, info):
        """
        Init the peer with given info dict
        :param info: Dict including all info, e.g.,
        :return: True or False
        """
        if 'url' in info:
            self._url = info['url']
        if 'grpc_options' in info:
            self._grpc_options = info['grpc_options']
        if 'tlsCACerts' in info:
            self._tlsCACerts = info['tlsCACerts']
        if 'registrar' in info:
            self._registrar = info['registrar']
        return True


def create_ca(name, info):
    """ Factory method to construct a ca instance

    Args:
        name: Name of the ca
        info: Info dict for initialization

    Returns: an organization instance
    """
    ca = certificateAuthority(name=name)
    ca.init_with_bundle(info)
    return ca



# Copyright IBM Corp. 2016 All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import os
from abc import ABCMeta, abstractmethod

import rx
import six


@six.add_metaclass(ABCMeta)
class KeyValueStore(object):
    """ An key value store for blockchain application state persistence. """

    @abstractmethod
    def set_value(self, key, value):
        """Set a value with a specific key.

        :param key: key
        :param value: value

        """

    @abstractmethod
    def get_value(self, key):
        """Get a value with a specific key.

        :param key: key

        :return: value
        """

    @abstractmethod
    def async_set_value(self, key, value, scheduler=None):
        """Set a value with a specific key.

        :param scheduler: scheduler
        :param key: key
        :param value: value

        :return:a future object
        """

    @abstractmethod
    def async_get_value(self, key, scheduler=None):
        """Get a value with a specific key.

        :param scheduler: scheduler
        :param key: key

        :return:a future object
        """


class FileKeyValueStore(KeyValueStore):
    """ A key value store implementation based file system. """

    def __init__(self, path):
        """Init the file key value store.

        :param path: path of key value store
        :return:
        """
        self.path = path
        _make_dir(path)

    def set_value(self, key, value):
        """Set a value with a specific key.

        Args:
            key: key
            value: value

        Returns: True when success
        Raises: File manipulate exceptions

        """
        file_path = os.path.join(self.path, key)
        with open(file_path, 'w') as f:
            f.write(value)
        return True

    def get_value(self, key):
        """Get a value with a specific key.

        :param key: key
        :return: value
        """
        try:
            file_path = os.path.join(self.path, key)
            with open(file_path) as f:
                return f.read()
        except IOError:
            return None

    def async_get_value(self, key, scheduler=None):
        """Get a value with a specific key.

        :param scheduler: scheduler
        :param key: key

        :return:a future object
        """
        return rx.start(lambda: self.get_value(key), scheduler)

    def async_set_value(self, key, value, scheduler=None):
        """Set a value with a specific key.

        :param scheduler: scheduler
        :param key: key
        :param value: value

        :return:a future object
        """
        return rx.start(lambda: self.set_value(key, value), scheduler)

    def get_attrs(self):
        return ",".join("{}={}"
                        .format(k, getattr(self, k))
                        for k in self.__dict__.keys())

    def __str__(self):
        return "[{}:{}]".format(self.__class__.__name__, self.get_attrs())


def _make_dir(path):
    try:
        os.makedirs(path)
    except OSError:
        if not os.path.isdir(path):
            raise


def file_key_value_store(path):
    """Factory method for creating file key value store.

    :param path: path

    :return an instance of file key value store
    """
    return FileKeyValueStore(path)



# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import unittest
from hfc.fabric.peer import Peer

DEFAULT_PEER_ENDPOINT = 'localhost:7051'
CUSTOM_PEER_ENDPOINT = 'peer:7051'


class PeerTest(unittest.TestCase):

    def setUp(self):
        self.default_peer_endpoint = DEFAULT_PEER_ENDPOINT
        self.custom_peer_endpoint = CUSTOM_PEER_ENDPOINT

    def test_create_peer_default_endpoint(self):
        peer = Peer()
        self.assertEqual(peer.endpoint, self.default_peer_endpoint)

    def test_create_peer_custom_endpoint(self):
        peer = Peer(name="test_peer", endpoint=self.custom_peer_endpoint)
        self.assertEqual(peer.endpoint, self.custom_peer_endpoint)


if __name__ == '__main__':
    unittest.main()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/common/ledger.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/common/ledger.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/common'),
  serialized_pb=_b('\n\x1ehfc/protos/common/ledger.proto\x12\x06\x63ommon\"U\n\x0e\x42lockchainInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x18\n\x10\x63urrentBlockHash\x18\x02 \x01(\x0c\x12\x19\n\x11previousBlockHash\x18\x03 \x01(\x0c\x42S\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/commonb\x06proto3')
)




_BLOCKCHAININFO = _descriptor.Descriptor(
  name='BlockchainInfo',
  full_name='common.BlockchainInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='common.BlockchainInfo.height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currentBlockHash', full_name='common.BlockchainInfo.currentBlockHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previousBlockHash', full_name='common.BlockchainInfo.previousBlockHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=127,
)

DESCRIPTOR.message_types_by_name['BlockchainInfo'] = _BLOCKCHAININFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockchainInfo = _reflection.GeneratedProtocolMessageType('BlockchainInfo', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKCHAININFO,
  __module__ = 'hfc.protos.common.ledger_pb2'
  # @@protoc_insertion_point(class_scope:common.BlockchainInfo)
  ))
_sym_db.RegisterMessage(BlockchainInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/common/configuration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/common/configuration.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/common'),
  serialized_pb=_b('\n%hfc/protos/common/configuration.proto\x12\x06\x63ommon\" \n\x10HashingAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x19\x42lockDataHashingStructure\x12\r\n\x05width\x18\x01 \x01(\r\"%\n\x10OrdererAddresses\x12\x11\n\taddresses\x18\x01 \x03(\t\"\x1a\n\nConsortium\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x95\x01\n\x0c\x43\x61pabilities\x12<\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0b\x32&.common.Capabilities.CapabilitiesEntry\x1aG\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.common.Capability:\x02\x38\x01\"\x0c\n\nCapabilityBS\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/commonb\x06proto3')
)




_HASHINGALGORITHM = _descriptor.Descriptor(
  name='HashingAlgorithm',
  full_name='common.HashingAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='common.HashingAlgorithm.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=81,
)


_BLOCKDATAHASHINGSTRUCTURE = _descriptor.Descriptor(
  name='BlockDataHashingStructure',
  full_name='common.BlockDataHashingStructure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='common.BlockDataHashingStructure.width', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=125,
)


_ORDERERADDRESSES = _descriptor.Descriptor(
  name='OrdererAddresses',
  full_name='common.OrdererAddresses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='common.OrdererAddresses.addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=164,
)


_CONSORTIUM = _descriptor.Descriptor(
  name='Consortium',
  full_name='common.Consortium',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='common.Consortium.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=192,
)


_CAPABILITIES_CAPABILITIESENTRY = _descriptor.Descriptor(
  name='CapabilitiesEntry',
  full_name='common.Capabilities.CapabilitiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='common.Capabilities.CapabilitiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='common.Capabilities.CapabilitiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=344,
)

_CAPABILITIES = _descriptor.Descriptor(
  name='Capabilities',
  full_name='common.Capabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='common.Capabilities.capabilities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CAPABILITIES_CAPABILITIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=344,
)


_CAPABILITY = _descriptor.Descriptor(
  name='Capability',
  full_name='common.Capability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=358,
)

_CAPABILITIES_CAPABILITIESENTRY.fields_by_name['value'].message_type = _CAPABILITY
_CAPABILITIES_CAPABILITIESENTRY.containing_type = _CAPABILITIES
_CAPABILITIES.fields_by_name['capabilities'].message_type = _CAPABILITIES_CAPABILITIESENTRY
DESCRIPTOR.message_types_by_name['HashingAlgorithm'] = _HASHINGALGORITHM
DESCRIPTOR.message_types_by_name['BlockDataHashingStructure'] = _BLOCKDATAHASHINGSTRUCTURE
DESCRIPTOR.message_types_by_name['OrdererAddresses'] = _ORDERERADDRESSES
DESCRIPTOR.message_types_by_name['Consortium'] = _CONSORTIUM
DESCRIPTOR.message_types_by_name['Capabilities'] = _CAPABILITIES
DESCRIPTOR.message_types_by_name['Capability'] = _CAPABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HashingAlgorithm = _reflection.GeneratedProtocolMessageType('HashingAlgorithm', (_message.Message,), dict(
  DESCRIPTOR = _HASHINGALGORITHM,
  __module__ = 'hfc.protos.common.configuration_pb2'
  # @@protoc_insertion_point(class_scope:common.HashingAlgorithm)
  ))
_sym_db.RegisterMessage(HashingAlgorithm)

BlockDataHashingStructure = _reflection.GeneratedProtocolMessageType('BlockDataHashingStructure', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKDATAHASHINGSTRUCTURE,
  __module__ = 'hfc.protos.common.configuration_pb2'
  # @@protoc_insertion_point(class_scope:common.BlockDataHashingStructure)
  ))
_sym_db.RegisterMessage(BlockDataHashingStructure)

OrdererAddresses = _reflection.GeneratedProtocolMessageType('OrdererAddresses', (_message.Message,), dict(
  DESCRIPTOR = _ORDERERADDRESSES,
  __module__ = 'hfc.protos.common.configuration_pb2'
  # @@protoc_insertion_point(class_scope:common.OrdererAddresses)
  ))
_sym_db.RegisterMessage(OrdererAddresses)

Consortium = _reflection.GeneratedProtocolMessageType('Consortium', (_message.Message,), dict(
  DESCRIPTOR = _CONSORTIUM,
  __module__ = 'hfc.protos.common.configuration_pb2'
  # @@protoc_insertion_point(class_scope:common.Consortium)
  ))
_sym_db.RegisterMessage(Consortium)

Capabilities = _reflection.GeneratedProtocolMessageType('Capabilities', (_message.Message,), dict(

  CapabilitiesEntry = _reflection.GeneratedProtocolMessageType('CapabilitiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _CAPABILITIES_CAPABILITIESENTRY,
    __module__ = 'hfc.protos.common.configuration_pb2'
    # @@protoc_insertion_point(class_scope:common.Capabilities.CapabilitiesEntry)
    ))
  ,
  DESCRIPTOR = _CAPABILITIES,
  __module__ = 'hfc.protos.common.configuration_pb2'
  # @@protoc_insertion_point(class_scope:common.Capabilities)
  ))
_sym_db.RegisterMessage(Capabilities)
_sym_db.RegisterMessage(Capabilities.CapabilitiesEntry)

Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), dict(
  DESCRIPTOR = _CAPABILITY,
  __module__ = 'hfc.protos.common.configuration_pb2'
  # @@protoc_insertion_point(class_scope:common.Capability)
  ))
_sym_db.RegisterMessage(Capability)


DESCRIPTOR._options = None
_CAPABILITIES_CAPABILITIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/chaincode.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.common import policies_pb2 as hfc_dot_protos_dot_common_dot_policies__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/chaincode.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n\x1fhfc/protos/peer/chaincode.proto\x12\x06protos\x1a hfc/protos/common/policies.proto\":\n\x0b\x43haincodeID\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x90\x01\n\x0e\x43haincodeInput\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\x0c\x12<\n\x0b\x64\x65\x63orations\x18\x02 \x03(\x0b\x32\'.protos.ChaincodeInput.DecorationsEntry\x1a\x32\n\x10\x44\x65\x63orationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xdc\x01\n\rChaincodeSpec\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.protos.ChaincodeSpec.Type\x12)\n\x0c\x63haincode_id\x18\x02 \x01(\x0b\x32\x13.protos.ChaincodeID\x12%\n\x05input\x18\x03 \x01(\x0b\x32\x16.protos.ChaincodeInput\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\">\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06GOLANG\x10\x01\x12\x08\n\x04NODE\x10\x02\x12\x07\n\x03\x43\x41R\x10\x03\x12\x08\n\x04JAVA\x10\x04\"\xec\x01\n\x17\x43haincodeDeploymentSpec\x12-\n\x0e\x63haincode_spec\x18\x01 \x01(\x0b\x32\x15.protos.ChaincodeSpec\x12\x14\n\x0c\x63ode_package\x18\x03 \x01(\x0c\x12\x46\n\x08\x65xec_env\x18\x04 \x01(\x0e\x32\x34.protos.ChaincodeDeploymentSpec.ExecutionEnvironment\".\n\x14\x45xecutionEnvironment\x12\n\n\x06\x44OCKER\x10\x00\x12\n\n\x06SYSTEM\x10\x01J\x04\x08\x02\x10\x03R\x0e\x65\x66\x66\x65\x63tive_date\"a\n\x17\x43haincodeInvocationSpec\x12-\n\x0e\x63haincode_spec\x18\x01 \x01(\x0b\x32\x15.protos.ChaincodeSpecJ\x04\x08\x02\x10\x03R\x11id_generation_alg\"(\n\x0eLifecycleEvent\x12\x16\n\x0e\x63haincode_name\x18\x01 \x01(\t\"-\n\x07\x43\x44SData\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x14\n\x0cmetadatahash\x18\x02 \x01(\x0c\"\xe5\x01\n\rChaincodeData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04\x65scc\x18\x03 \x01(\t\x12\x0c\n\x04vscc\x18\x04 \x01(\t\x12/\n\x06policy\x18\x05 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelope\x12\x1d\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x0f.protos.CDSData\x12\n\n\x02id\x18\x07 \x01(\x0c\x12=\n\x14instantiation_policy\x18\x08 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelope*4\n\x14\x43onfidentialityLevel\x12\n\n\x06PUBLIC\x10\x00\x12\x10\n\x0c\x43ONFIDENTIAL\x10\x01\x42O\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_common_dot_policies__pb2.DESCRIPTOR,])

_CONFIDENTIALITYLEVEL = _descriptor.EnumDescriptor(
  name='ConfidentialityLevel',
  full_name='protos.ConfidentialityLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIDENTIAL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1166,
  serialized_end=1218,
)
_sym_db.RegisterEnumDescriptor(_CONFIDENTIALITYLEVEL)

ConfidentialityLevel = enum_type_wrapper.EnumTypeWrapper(_CONFIDENTIALITYLEVEL)
PUBLIC = 0
CONFIDENTIAL = 1


_CHAINCODESPEC_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='protos.ChaincodeSpec.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOLANG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JAVA', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=443,
  serialized_end=505,
)
_sym_db.RegisterEnumDescriptor(_CHAINCODESPEC_TYPE)

_CHAINCODEDEPLOYMENTSPEC_EXECUTIONENVIRONMENT = _descriptor.EnumDescriptor(
  name='ExecutionEnvironment',
  full_name='protos.ChaincodeDeploymentSpec.ExecutionEnvironment',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOCKER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=676,
  serialized_end=722,
)
_sym_db.RegisterEnumDescriptor(_CHAINCODEDEPLOYMENTSPEC_EXECUTIONENVIRONMENT)


_CHAINCODEID = _descriptor.Descriptor(
  name='ChaincodeID',
  full_name='protos.ChaincodeID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='protos.ChaincodeID.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ChaincodeID.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='protos.ChaincodeID.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=135,
)


_CHAINCODEINPUT_DECORATIONSENTRY = _descriptor.Descriptor(
  name='DecorationsEntry',
  full_name='protos.ChaincodeInput.DecorationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protos.ChaincodeInput.DecorationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protos.ChaincodeInput.DecorationsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=282,
)

_CHAINCODEINPUT = _descriptor.Descriptor(
  name='ChaincodeInput',
  full_name='protos.ChaincodeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='protos.ChaincodeInput.args', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decorations', full_name='protos.ChaincodeInput.decorations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHAINCODEINPUT_DECORATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=282,
)


_CHAINCODESPEC = _descriptor.Descriptor(
  name='ChaincodeSpec',
  full_name='protos.ChaincodeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='protos.ChaincodeSpec.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chaincode_id', full_name='protos.ChaincodeSpec.chaincode_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='protos.ChaincodeSpec.input', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='protos.ChaincodeSpec.timeout', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHAINCODESPEC_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=505,
)


_CHAINCODEDEPLOYMENTSPEC = _descriptor.Descriptor(
  name='ChaincodeDeploymentSpec',
  full_name='protos.ChaincodeDeploymentSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincode_spec', full_name='protos.ChaincodeDeploymentSpec.chaincode_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code_package', full_name='protos.ChaincodeDeploymentSpec.code_package', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_env', full_name='protos.ChaincodeDeploymentSpec.exec_env', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHAINCODEDEPLOYMENTSPEC_EXECUTIONENVIRONMENT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=744,
)


_CHAINCODEINVOCATIONSPEC = _descriptor.Descriptor(
  name='ChaincodeInvocationSpec',
  full_name='protos.ChaincodeInvocationSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincode_spec', full_name='protos.ChaincodeInvocationSpec.chaincode_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=843,
)


_LIFECYCLEEVENT = _descriptor.Descriptor(
  name='LifecycleEvent',
  full_name='protos.LifecycleEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincode_name', full_name='protos.LifecycleEvent.chaincode_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=885,
)


_CDSDATA = _descriptor.Descriptor(
  name='CDSData',
  full_name='protos.CDSData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='protos.CDSData.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadatahash', full_name='protos.CDSData.metadatahash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=932,
)


_CHAINCODEDATA = _descriptor.Descriptor(
  name='ChaincodeData',
  full_name='protos.ChaincodeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ChaincodeData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='protos.ChaincodeData.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='escc', full_name='protos.ChaincodeData.escc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vscc', full_name='protos.ChaincodeData.vscc', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='protos.ChaincodeData.policy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='protos.ChaincodeData.data', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.ChaincodeData.id', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instantiation_policy', full_name='protos.ChaincodeData.instantiation_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=935,
  serialized_end=1164,
)

_CHAINCODEINPUT_DECORATIONSENTRY.containing_type = _CHAINCODEINPUT
_CHAINCODEINPUT.fields_by_name['decorations'].message_type = _CHAINCODEINPUT_DECORATIONSENTRY
_CHAINCODESPEC.fields_by_name['type'].enum_type = _CHAINCODESPEC_TYPE
_CHAINCODESPEC.fields_by_name['chaincode_id'].message_type = _CHAINCODEID
_CHAINCODESPEC.fields_by_name['input'].message_type = _CHAINCODEINPUT
_CHAINCODESPEC_TYPE.containing_type = _CHAINCODESPEC
_CHAINCODEDEPLOYMENTSPEC.fields_by_name['chaincode_spec'].message_type = _CHAINCODESPEC
_CHAINCODEDEPLOYMENTSPEC.fields_by_name['exec_env'].enum_type = _CHAINCODEDEPLOYMENTSPEC_EXECUTIONENVIRONMENT
_CHAINCODEDEPLOYMENTSPEC_EXECUTIONENVIRONMENT.containing_type = _CHAINCODEDEPLOYMENTSPEC
_CHAINCODEINVOCATIONSPEC.fields_by_name['chaincode_spec'].message_type = _CHAINCODESPEC
_CHAINCODEDATA.fields_by_name['policy'].message_type = hfc_dot_protos_dot_common_dot_policies__pb2._SIGNATUREPOLICYENVELOPE
_CHAINCODEDATA.fields_by_name['data'].message_type = _CDSDATA
_CHAINCODEDATA.fields_by_name['instantiation_policy'].message_type = hfc_dot_protos_dot_common_dot_policies__pb2._SIGNATUREPOLICYENVELOPE
DESCRIPTOR.message_types_by_name['ChaincodeID'] = _CHAINCODEID
DESCRIPTOR.message_types_by_name['ChaincodeInput'] = _CHAINCODEINPUT
DESCRIPTOR.message_types_by_name['ChaincodeSpec'] = _CHAINCODESPEC
DESCRIPTOR.message_types_by_name['ChaincodeDeploymentSpec'] = _CHAINCODEDEPLOYMENTSPEC
DESCRIPTOR.message_types_by_name['ChaincodeInvocationSpec'] = _CHAINCODEINVOCATIONSPEC
DESCRIPTOR.message_types_by_name['LifecycleEvent'] = _LIFECYCLEEVENT
DESCRIPTOR.message_types_by_name['CDSData'] = _CDSDATA
DESCRIPTOR.message_types_by_name['ChaincodeData'] = _CHAINCODEDATA
DESCRIPTOR.enum_types_by_name['ConfidentialityLevel'] = _CONFIDENTIALITYLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChaincodeID = _reflection.GeneratedProtocolMessageType('ChaincodeID', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEID,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeID)
  ))
_sym_db.RegisterMessage(ChaincodeID)

ChaincodeInput = _reflection.GeneratedProtocolMessageType('ChaincodeInput', (_message.Message,), dict(

  DecorationsEntry = _reflection.GeneratedProtocolMessageType('DecorationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CHAINCODEINPUT_DECORATIONSENTRY,
    __module__ = 'hfc.protos.peer.chaincode_pb2'
    # @@protoc_insertion_point(class_scope:protos.ChaincodeInput.DecorationsEntry)
    ))
  ,
  DESCRIPTOR = _CHAINCODEINPUT,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeInput)
  ))
_sym_db.RegisterMessage(ChaincodeInput)
_sym_db.RegisterMessage(ChaincodeInput.DecorationsEntry)

ChaincodeSpec = _reflection.GeneratedProtocolMessageType('ChaincodeSpec', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODESPEC,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeSpec)
  ))
_sym_db.RegisterMessage(ChaincodeSpec)

ChaincodeDeploymentSpec = _reflection.GeneratedProtocolMessageType('ChaincodeDeploymentSpec', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEDEPLOYMENTSPEC,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeDeploymentSpec)
  ))
_sym_db.RegisterMessage(ChaincodeDeploymentSpec)

ChaincodeInvocationSpec = _reflection.GeneratedProtocolMessageType('ChaincodeInvocationSpec', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEINVOCATIONSPEC,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeInvocationSpec)
  ))
_sym_db.RegisterMessage(ChaincodeInvocationSpec)

LifecycleEvent = _reflection.GeneratedProtocolMessageType('LifecycleEvent', (_message.Message,), dict(
  DESCRIPTOR = _LIFECYCLEEVENT,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.LifecycleEvent)
  ))
_sym_db.RegisterMessage(LifecycleEvent)

CDSData = _reflection.GeneratedProtocolMessageType('CDSData', (_message.Message,), dict(
  DESCRIPTOR = _CDSDATA,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.CDSData)
  ))
_sym_db.RegisterMessage(CDSData)

ChaincodeData = _reflection.GeneratedProtocolMessageType('ChaincodeData', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEDATA,
  __module__ = 'hfc.protos.peer.chaincode_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeData)
  ))
_sym_db.RegisterMessage(ChaincodeData)


DESCRIPTOR._options = None
_CHAINCODEINPUT_DECORATIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)
